@@ -302,7 +302,7 @@ FullTable1 <- function(data, strata = NULL, vars = NULL,
         # get N (%)
         tableout[, grplvl] <- as.data.frame(t((datafile %>%
           tidyr::drop_na(tidyselect::all_of(outcome)) %>%
-          dplyr::group_by_at(c(groupvar, outcome)) %>%
+          dplyr::group_by_at(c(groupvar, outcome), .drop=FALSE) %>%
           dplyr::select_at(outcome) %>%
           tally() %>%
           dplyr::ungroup() %>%
@@ -342,7 +342,7 @@ FullTable1 <- function(data, strata = NULL, vars = NULL,
         tableout$Variable <- outcome
         tableout[2:(1 + length(levels(y))), grplvl] <- datafile %>%
           tidyr::drop_na(tidyselect::all_of(outcome)) %>%
-          dplyr::group_by_at(c(groupvar, outcome)) %>%
+          dplyr::group_by_at(c(groupvar, outcome), .drop=FALSE) %>%
           dplyr::select_at(outcome) %>%
           tally() %>%
           dplyr::ungroup() %>%
