@@ -28,7 +28,7 @@ apastat <- function(test,
                     es = c(TRUE, FALSE),
                     ci = c(TRUE, FALSE),
                     var = NULL) {
-  if (class(test) == "htest") {
+  if (inherits(test, what = "htest")) {
     # t-test
     if (grepl("t-test", test$method)) {
       out <- paste0(
@@ -130,8 +130,8 @@ apastat <- function(test,
   }
 
   # lm
-  if (class(test) == "lm" | class(test) == "summary.lm") {
-    if (class(test) == "lm") {
+  if (inherits(test, what = "lm") | inherits(test, what = "summary.lm")) {
+    if (inherits(test, what = "lm")) {
       tmp <- summary(test)
     } else {
       tmp <- test
@@ -183,7 +183,7 @@ apastat <- function(test,
             )
           )
         ),
-        ifelse(es[1] == TRUE & (class(test) == "lm") &
+        ifelse(es[1] == TRUE & (inherits(test, what = "lm")) &
           length(test$xlevels[[var]]) == 2,
         paste0(
           ", d=",
